==> cc_sphinx_changelog-0.5.0.tar.gz: cc_sphinx_changelog-0.5.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('CHANGELOG.md') as history_file:
    history = history_file.read()

requirements = ["gitpython", "backpedal"]

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="Paul Gierz",
    author_email='pgierz@awi.de',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="Automatically generates a releases-style changelog based on conventional commit messages.",
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='cc_sphinx_changelog',
    name='cc_sphinx_changelog',
    packages=find_packages(include=['cc_sphinx_changelog']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/pgierz/cc_sphinx_changelog',
    version='0.5.0',
    zip_safe=False,
)

==> cc_sphinx_changelog-0.5.2.tar.gz: cc_sphinx_changelog-0.5.2/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('CHANGELOG.md') as history_file:
    history = history_file.read()

requirements = ["gitpython", "backpedal", "ansiwrap", "crayons"]

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="Paul Gierz",
    author_email='pgierz@awi.de',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="Automatically generates a releases-style changelog based on conventional commit messages.",
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='cc_sphinx_changelog',
    name='cc_sphinx_changelog',
    packages=find_packages(include=['cc_sphinx_changelog']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/pgierz/cc_sphinx_changelog',
    version='0.5.2',
    zip_safe=False,
)
